diff --git a/atd.c b/atd.c
index bf28102..ed52327 100644
--- a/atd.c
+++ b/atd.c
@@ -468,6 +468,18 @@ run_file(const char *filename, uid_t uid, gid_t gid)
     if (open(filename, O_RDONLY) != STDIN_FILENO)
 	perr("Open of jobfile failed");
 
+    /* some sendmail implementations are confused if stdout, stderr are
+     * not available, so let them point to /dev/null
+     */
+    if ((fd_in = open("/dev/null", O_WRONLY)) < 0)
+	perr("Could not open /dev/null.");
+    if (dup2(fd_in, STDOUT_FILENO) < 0)
+	perr("Could not use /dev/null as standard output.");
+    if (dup2(fd_in, STDERR_FILENO) < 0)
+	perr("Could not use /dev/null as standard error.");
+    if (fd_in != STDOUT_FILENO && fd_in != STDERR_FILENO)
+	close(fd_in);
+
     unlink(filename);
 
     /* The job is now finished.  We can delete its input file.
diff --git a/debian/changelog b/debian/changelog
index c003ee1..80fba2b 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,3 +1,9 @@
+at (3.1.11-1+ab1) UNRELEASED; urgency=low
+
+  * make stdout, stderr available to sendmail process (Closes: #316442)
+
+ -- Ansgar Burchardt <ansgar@43-1.org>  Sun, 15 Nov 2009 20:36:44 +0900
+
 at (3.1.11-1) unstable; urgency=low
 
   * New "upstream" release:
